==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/link/lang/tt.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'tt', {
	acccessKey: 'Access Key', // MISSING
	advanced: 'Киңәйтелгән көйләүләр',
	advisoryContentType: 'Advisory Content Type', // MISSING
	advisoryTitle: 'Киңәш исем',
	anchor: {
		toolbar: 'Якорь',
		menu: 'Якорьне үзгәртү',
		title: 'Якорь үзлекләре',
		name: 'Якорь исеме',
		errorName: 'Якорьнең исемен языгыз',
		remove: 'Якорьне бетерү'
	},
	anchorId: 'Элемент идентификаторы буенча',
	anchorName: 'Якорь исеме буенча',
	charset: 'Linked Resource Charset', // MISSING
	cssClasses: 'Стильләр класслары',
	emailAddress: 'Электрон почта адресы',
	emailBody: 'Хат эчтәлеге',
	emailSubject: 'Хат темасы',
	id: 'Идентификатор',
	info: 'Сылталама тасвирламасы',
	langCode: 'Тел коды',
	langDir: 'Язылыш юнəлеше',
	langDirLTR: 'Сулдан уңга язылыш (LTR)',
	langDirRTL: 'Уңнан сулга язылыш (RTL)',
	menu: 'Сылталамаyны үзгәртү',
	name: 'Исем',
	noAnchors: '(Әлеге документта якорьләр табылмады)',
	noEmail: 'Электрон почта адресын языгыз',
	noUrl: 'Сылталаманы языгыз',
	other: '<бүтән>',
	popupDependent: 'Dependent (Netscape)', // MISSING
	popupFeatures: 'Popup Window Features', // MISSING
	popupFullScreen: 'Full Screen (IE)', // MISSING
	popupLeft: 'Left Position', // MISSING
	popupLocationBar: 'Location Bar', // MISSING
	popupMenuBar: 'Menu Bar', // MISSING
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Scroll Bars', // MISSING
	popupStatusBar: 'Status Bar', // MISSING
	popupToolbar: 'Toolbar', // MISSING
	popupTop: 'Top Position', // MISSING
	rel: 'Бәйләнеш',
	selectAnchor: 'Якорьне сайлау',
	styles: 'Стиль',
	tabIndex: 'Tab Index', // MISSING
	target: 'Максат',
	targetFrame: '<frame>', // MISSING
	targetFrameName: 'Target Frame Name', // MISSING
	targetPopup: '<popup window>', // MISSING
	targetPopupName: 'Popup Window Name', // MISSING
	title: 'Сылталама',
	toAnchor: 'Якорьне текст белән бәйләү',
	toEmail: 'Электрон почта',
	toUrl: 'Сылталама',
	toolbar: 'Сылталама',
	type: 'Сылталама төре',
	unlink: 'Сылталаманы бетерү',
	upload: 'Йөкләү'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/tt.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'tt', {
	acccessKey: 'Access Key', // MISSING
	advanced: 'Киңәйтелгән көйләүләр',
	advisoryContentType: 'Advisory Content Type', // MISSING
	advisoryTitle: 'Киңәш исем',
	anchor: {
		toolbar: 'Якорь',
		menu: 'Якорьне үзгәртү',
		title: 'Якорь үзлекләре',
		name: 'Якорь исеме',
		errorName: 'Якорьнең исемен языгыз',
		remove: 'Якорьне бетерү'
	},
	anchorId: 'Элемент идентификаторы буенча',
	anchorName: 'Якорь исеме буенча',
	charset: 'Linked Resource Charset', // MISSING
	cssClasses: 'Стильләр класслары',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Электрон почта адресы',
	emailBody: 'Хат эчтәлеге',
	emailSubject: 'Хат темасы',
	id: 'Идентификатор',
	info: 'Сылталама тасвирламасы',
	langCode: 'Тел коды',
	langDir: 'Язылыш юнəлеше',
	langDirLTR: 'Сулдан уңга язылыш (LTR)',
	langDirRTL: 'Уңнан сулга язылыш (RTL)',
	menu: 'Сылталамаyны үзгәртү',
	name: 'Исем',
	noAnchors: '(Әлеге документта якорьләр табылмады)',
	noEmail: 'Электрон почта адресын языгыз',
	noUrl: 'Сылталаманы языгыз',
	noTel: 'Please type the phone number', // MISSING
	other: '<бүтән>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Бәйле (Netscape)',
	popupFeatures: 'Popup Window Features', // MISSING
	popupFullScreen: 'Тулы экран (IE)',
	popupLeft: 'Left Position', // MISSING
	popupLocationBar: 'Location Bar', // MISSING
	popupMenuBar: 'Menu Bar', // MISSING
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Scroll Bars', // MISSING
	popupStatusBar: 'Status Bar', // MISSING
	popupToolbar: 'Toolbar', // MISSING
	popupTop: 'Top Position', // MISSING
	rel: 'Бәйләнеш',
	selectAnchor: 'Якорьне сайлау',
	styles: 'Стиль',
	tabIndex: 'Tab Index', // MISSING
	target: 'Максат',
	targetFrame: '<frame>',
	targetFrameName: 'Target Frame Name', // MISSING
	targetPopup: '<popup window>',
	targetPopupName: 'Попап тәрәзәсе исеме',
	title: 'Сылталама',
	toAnchor: 'Якорьне текст белән бәйләү',
	toEmail: 'Электрон почта',
	toUrl: 'Сылталама',
	toPhone: 'Phone', // MISSING
	toolbar: 'Сылталама',
	type: 'Сылталама төре',
	unlink: 'Сылталаманы бетерү',
	upload: 'Йөкләү'
} );
